@@ -1,7 +1,5 @@
-package Mason::Moose;
-BEGIN {
-  $Mason::Moose::VERSION = '2.15';
-}
+package Mason::Moose;    ## no critic (Moose::RequireMakeImmutable)
+$Mason::Moose::VERSION = '2.24';
 use Moose                      ();
 use MooseX::HasDefaults::RO    ();
 use MooseX::StrictConstructor  ();
@@ -17,17 +15,18 @@ sub init_meta {
     my $for_class = $params{for_class};
     Method::Signatures::Simple->import( into => $for_class );
     Moose->init_meta(@_);
-    MooseX::StrictConstructor->init_meta(@_);
-    MooseX::HasDefaults::RO->init_meta(@_);
+    MooseX::StrictConstructor->import( { into => $for_class } );
+    MooseX::HasDefaults::RO->import( { into => $for_class } );
     {
         no strict 'refs';
-        *{ $for_class . '::CLASS' } = sub () { $for_class };    # like CLASS.pm
+        my $temp = $for_class;
+        *{ $for_class . '::CLASS' } = sub () { $temp };    # like CLASS.pm
     }
 }
 
 1;
 
-
+__END__
 
 =pod
 
@@ -61,13 +60,9 @@ Jonathan Swartz <swartz@pobox.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jonathan Swartz.
+This software is copyright (c) 2012 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
