@@ -1,7 +1,5 @@
 package Mason::Test::RootClass::Compilation;
-BEGIN {
-  $Mason::Test::RootClass::Compilation::VERSION = '2.15';
-}
+$Mason::Test::RootClass::Compilation::VERSION = '2.24';
 use Moose;
 extends 'Mason::Compilation';
 
@@ -10,4 +8,6 @@ before 'parse' => sub {
     print STDERR "starting compilation parse - " . $self->path . "\n";
 };
 
+__PACKAGE__->meta->make_immutable();
+
 1;
