@@ -1,7 +1,5 @@
 package Mason::Test::RootClass::Request;
-BEGIN {
-  $Mason::Test::RootClass::Request::VERSION = '2.15';
-}
+$Mason::Test::RootClass::Request::VERSION = '2.24';
 use Moose;
 extends 'Mason::Request';
 
@@ -15,4 +13,6 @@ before 'comp' => sub {
     print STDERR "starting request comp - $path\n";
 };
 
+__PACKAGE__->meta->make_immutable();
+
 1;
